require 'rails_helper'

RSpec.describe 'RFR script' do
  let!(:hr) { create(:complete_request, is_active: true, unique_numbers: ['1110121021545G1104']) }
  let!(:setting) { create(:setting, key: 'hermes_rfr_settings', values: { change_minus_two_date: '05/01/2021', change_minus_two_year: '2020' }) }
  let!(:hrf) { hr.housing_request_folder}

  subject { load Hermes::Engine.root.join('scripts', 'script_RFR.rb') }

  after do 
    Dir.glob(Rails.root.join('*script_RFR*')).each do |file_path|
      File.delete(file_path)
    end
  end 

  before do 
    Timecop.freeze(Date.new(2021, 1, 2)) do 
      hr.update_request_from_sne(nil)
    end
  end 

  it 'default' do 
    hr.reload
    hrf.reload
    imposition_documents = hrf.required_documents.select { |hash| hash[:type].include?("imposition") }

    expect(hr.reference_tax_revenues).to eq(22000)
    expect(imposition_documents.length).to eq(4)
    expect(imposition_documents.first[:type]).to eq("Avis d'imposition 2020 sur les revenus de l'année 2019")
  end 

  it 'after' do
    Timecop.freeze(Date.new(2021, 1, 6)) do 
      subject
      
      hr.reload
      hrf.reload
      imposition_documents = hrf.required_documents.select { |hash| hash[:type].include?("imposition") }
  
      expect(hr.reference_tax_revenues).to eq(22500)
      expect(imposition_documents.length).to eq(3)
      expect(imposition_documents.first[:type]).to eq("Avis d'imposition 2021 sur les revenus de l'année 2020")
    end 
  end
end 